@@ -2,6 +2,7 @@
     Base settings for a Django project installed in Yunohost.
     All values should not depent on YunoHost app settings.
 """
+import logging as __logging
 
 
 # -----------------------------------------------------------------------------
@@ -21,7 +22,7 @@ INSTALLED_APPS = [
     'django.contrib.messages',
     'django.contrib.staticfiles',
     'axes',  # https://github.com/jazzband/django-axes
-    'django_yunohost_integration',
+    'django_yunohost_integration.apps.YunohostIntegrationConfig',
 ]
 
 # -----------------------------------------------------------------------------
@@ -75,7 +76,7 @@ AUTHENTICATION_BACKENDS = (
 )
 
 LOGIN_REDIRECT_URL = None
-LOGIN_URL = '/yunohost/sso/'
+LOGIN_URL = 'ssowat-login'
 LOGOUT_REDIRECT_URL = '/yunohost/sso/'
 # /yunohost/sso/?action=logout
 
@@ -105,23 +106,79 @@ SECURE_HSTS_SECONDS = 3600
 SECURE_HSTS_INCLUDE_SUBDOMAINS = True
 
 # _____________________________________________________________________________
-# Setting below, should be overwritten!
+# cut 'pathname' in log output
+
+old_factory = __logging.getLogRecordFactory()
+
+
+def cut_path(pathname, max_length):
+    if len(pathname) <= max_length:
+        return pathname
+    return f'...{pathname[-(max_length - 3):]}'
+
+
+def record_factory(*args, **kwargs):
+    record = old_factory(*args, **kwargs)
+    record.cut_path = cut_path(record.pathname, 30)
+    return record
+
+
+__logging.setLogRecordFactory(record_factory)
+
+# -----------------------------------------------------------------------------
 
 LOGGING = {
     'version': 1,
-    'disable_existing_loggers': False,
+    'disable_existing_loggers': True,
     'formatters': {
         'verbose': {
             'format': '{asctime} {levelname} {name} {module}.{funcName} {message}',
             'style': '{',
         },
+        'colored': {  # https://github.com/borntyping/python-colorlog
+            '()': 'colorlog.ColoredFormatter',
+            'format': '%(log_color)s%(asctime)s %(levelname)8s %(cut_path)s:%(lineno)-3s %(message)s',
+        },
+    },
+    'handlers': {
+        'console': {
+            'level': 'DEBUG',
+            'class': 'colorlog.StreamHandler',
+            'formatter': 'colored',
+        },
+        'mail_admins': {
+            'level': 'ERROR',
+            'formatter': 'verbose',
+            'class': 'django.utils.log.AdminEmailHandler',
+            'include_html': True,
+        },
+        'log_file': {
+            'level': 'INFO',
+            'class': 'logging.handlers.WatchedFileHandler',
+            'formatter': 'verbose',
+            'filename': '/tmp/django_yunohost_integration.log',  # <<< should be overwritten!
+        },
+        'syslog': {
+            'level': 'INFO',
+            'class': 'django_tools.log_utils.syslog_handler.SyslogHandler',
+            'formatter': 'verbose',
+        },
     },
-    'handlers': {'console': {'class': 'logging.StreamHandler', 'formatter': 'verbose'}},
     'loggers': {
-        'django': {'handlers': ['console'], 'level': 'INFO', 'propagate': False},
-        'django.auth': {'handlers': ['console'], 'level': 'DEBUG', 'propagate': False},
-        'django.security': {'handlers': ['console'], 'level': 'DEBUG', 'propagate': False},
-        'django.request': {'handlers': ['console'], 'level': 'DEBUG', 'propagate': False},
-        'django_yunohost_integration': {'handlers': ['console'], 'level': 'DEBUG', 'propagate': False},
+        '': {
+            'handlers': ['syslog', 'log_file', 'mail_admins'],
+            'level': 'INFO',
+            'propagate': False,
+        },
+        'django': {
+            'handlers': ['syslog', 'log_file', 'mail_admins'],
+            'level': 'INFO',
+            'propagate': False,
+        },
+        'axes': {
+            'handlers': ['syslog', 'log_file', 'mail_admins'],
+            'level': 'WARNING',
+            'propagate': False,
+        },
     },
 }
