@@ -2,7 +2,6 @@
     Create a YunoHost package local test
 """
 import argparse
-import inspect
 import json
 import os
 import shlex
@@ -10,10 +9,15 @@ import subprocess
 import sys
 from pathlib import Path
 
-from django_yunohost_integration.path_utils import assert_is_dir, assert_is_file
+from django_tools.unittest_utils.assertments import assert_is_dir, assert_is_file
+
+import django_yunohost_integration
 from django_yunohost_integration.test_utils import generate_basic_auth
 
 
+BASE_PATH = Path(django_yunohost_integration.__file__).parent
+
+
 def verbose_check_call(command, verbose=True, extra_env=None, **kwargs):
     """ 'verbose' version of subprocess.check_call() """
     if verbose:
@@ -34,17 +38,17 @@ def verbose_check_call(command, verbose=True, extra_env=None, **kwargs):
     subprocess.check_call(popenargs, universal_newlines=True, env=env, **kwargs)
 
 
-def call_manage_py(final_home_path, args, extra_env=None):
-    assert_is_file(final_home_path / 'manage.py')
+def call_manage_py(final_path, args, extra_env=None):
+    assert_is_file(final_path / 'manage.py')
     verbose_check_call(
         command=f'{sys.executable} manage.py {args}',
         extra_env=extra_env,
-        cwd=final_home_path,
+        cwd=final_path,
     )
 
 
-def copy_patch(src_file, replaces, final_home_path):
-    dst_file = final_home_path / src_file.name
+def copy_patch(src_file, replaces, final_path):
+    dst_file = final_path / src_file.name
     print(f'{src_file} -> {dst_file}')
 
     with src_file.open('r') as f:
@@ -60,7 +64,9 @@ def copy_patch(src_file, replaces, final_home_path):
         f.write(content)
 
 
-def create_local_test(django_settings_path, destination, runserver=False):
+def create_local_test(
+    django_settings_path, destination, runserver=False, extra_replacements: dict = None
+):
     django_settings_path = django_settings_path.resolve()
     assert_is_file(django_settings_path)
 
@@ -98,24 +104,34 @@ def create_local_test(django_settings_path, destination, runserver=False):
 
     assert_is_dir(destination)
 
-    final_home_path = destination / 'opt_yunohost'
-    final_www_path = destination / 'var_www'
+    final_path = destination / 'opt_yunohost'
+    public_path = destination / 'var_www'
     log_file = destination / f'var_log_{project_name}.log'
 
     REPLACES = {
-        '__FINAL_HOME_PATH__': str(final_home_path),
-        '__FINAL_WWW_PATH__': str(final_www_path),
         '__LOG_FILE__': str(log_file),
         '__PATH_URL__': 'app_path',
         '__DOMAIN__': '127.0.0.1',
         'django.db.backends.postgresql': 'django.db.backends.sqlite3',
         "'NAME': '__APP__',": f"'NAME': '{destination / 'test_db.sqlite'}',",
         'django_redis.cache.RedisCache': 'django.core.cache.backends.dummy.DummyCache',
-        # Just use the default logging setup from django_yunohost_integration project:
-        'LOGGING = {': 'HACKED_DEACTIVATED_LOGGING = {',
+        "'syslog'": "'console'",  # Log to console for local test
+        #
+        # config_panel.toml settings:
+        '__DEBUG_ENABLED__': '1',
+        '__LOG_LEVEL__': 'DEBUG',
+        '__ADMIN__': 'The Admin Username',
+        '__DEFAULT_FROM_EMAIL__': 'default-from-email@test.intranet',
+        #
+        # New variable names, for "ynh_add_config" usage:
+        '__FINALPATH__': str(final_path),
+        '__PUBLIC_PATH__': str(public_path),
+        '__ADMIN_EMAIL__': 'admin-email@test.intranet',
     }
+    if extra_replacements:
+        REPLACES.update(extra_replacements)
 
-    for p in (final_home_path, final_www_path):
+    for p in (final_path, public_path):
         if p.is_dir():
             print(f'Already exists: "{p}", ok.')
         else:
@@ -129,29 +145,20 @@ def create_local_test(django_settings_path, destination, runserver=False):
     assert_is_file(conf_path / 'urls.py')
 
     for src_file in conf_path.glob('*.py'):
-        copy_patch(src_file=src_file, replaces=REPLACES, final_home_path=final_home_path)
+        copy_patch(src_file=src_file, replaces=REPLACES, final_path=final_path)
 
-    local_settings_path = final_home_path / 'local_settings.py'
-    local_settings_path.write_text(inspect.cleandoc('''
-        # Only for local test run
-
-        import os
-
-
-        if os.environ.get('ENV_TYPE', None) == 'local':
-            print(f'Activate settings overwrite by {__file__}')
-            DEBUG = True
-            SECURE_SSL_REDIRECT = False  # Don't redirect http to https
-            SERVE_FILES = True  # May used in urls.py
-            AUTH_PASSWORD_VALIDATORS = []  # accept all passwords
-    '''))
+    local_settings_path = final_path / 'local_settings.py'
+    local_settings_source = Path(BASE_PATH / 'local_settings_source.py')
+    local_settings = f'# source file: {local_settings_source}\n'
+    local_settings += local_settings_source.read_text()
+    local_settings_path.write_text(local_settings)
 
     # call "local_test/manage.py" via subprocess:
-    call_manage_py(final_home_path, 'check --deploy')
+    call_manage_py(final_path, 'check --deploy')
     if runserver:
-        call_manage_py(final_home_path, 'migrate --no-input')
-        call_manage_py(final_home_path, 'collectstatic --no-input')
-        call_manage_py(final_home_path, 'create_superuser --username="test"')
+        call_manage_py(final_path, 'migrate --no-input')
+        call_manage_py(final_path, 'collectstatic --no-input')
+        call_manage_py(final_path, 'create_superuser --username="test"')
 
         os.environ['DJANGO_SETTINGS_MODULE'] = django_settings_name
 
@@ -166,14 +173,14 @@ def create_local_test(django_settings_path, destination, runserver=False):
 
         try:
             call_manage_py(
-                final_home_path,
+                final_path,
                 'runserver',
                 extra_env={'ENV_TYPE': 'local'}  # Activate local_settings.py overwrites
             )
         except KeyboardInterrupt:
             print('\nBye ;)')
 
-    return final_home_path
+    return final_path
 
 
 def cli():
